@@ -1,11 +1,10 @@
 import { Widget } from '@lumino/widgets';
 import { IRenderMime } from '@jupyterlab/rendermime-interfaces';
-import * as THREE from 'three';
-import decoder from './decoder';
-import { OrbitControls } from 'three/examples/jsm/controls/OrbitControls';
-import { disposeScene, meshify } from './utilities';
 import { imageIcon } from '@jupyterlab/ui-components';
 
+import { THREE, disposeScene, meshify } from './utilities';
+import decoder from './decoder';
+
 const MIME_TYPE = 'application/octet-stream';
 
 export class GeomWidget extends Widget implements IRenderMime.IRenderer {
@@ -57,7 +56,7 @@ export class GeomWidget extends Widget implements IRenderMime.IRenderer {
         this.renderer.shadowMap.type = THREE.PCFSoftShadowMap;
         this.renderer.render(this.scene, this.camera);
 
-        this.orbitControl = new OrbitControls(this.camera, this.renderer.domElement);
+        this.orbitControl = new THREE.OrbitControls(this.camera, this.renderer.domElement);
         this.orbitControl.enableZoom = true;
         this.orbitControl.addEventListener('change', () => {
             this.renderer.render(this.scene, this.camera)
@@ -109,7 +108,7 @@ export class GeomWidget extends Widget implements IRenderMime.IRenderer {
         return new Promise((resolve, reject) => {
             decoder.decode({ data })
                 .then(res => {
-                    this.setMeshs(meshify(res.results));
+                    this.setMeshs(meshify(res.geoms));
                     resolve();
                 })
                 .catch(() => reject());
